@@ -49,7 +49,8 @@ void draw_cards () {
 	  image = get_card_picture(card->suit, card->value);
 	
 	gdk_gc_set_clip_origin(draw_gc, x, y);
-	gdk_draw_pixmap(surface, draw_gc, image, 0, 0, x, y, -1, -1);
+	if (image != NULL)
+	  gdk_draw_pixmap(surface, draw_gc, image, 0, 0, x, y, -1, -1);
 	
 	x += hslot->dx; y += hslot->dy;
       }
@@ -64,13 +65,16 @@ void take_snapshot() {
   gdk_draw_rectangle (surface, draw_gc, TRUE, 0, 0, -1, -1);
 
   for (slot = get_slot_list(); slot; slot = slot->next) {
+    GdkPixmap *slot_pixmap;
     gdk_gc_set_clip_mask(draw_gc,mask); 
     gdk_gc_set_clip_origin(draw_gc, ((hslot_type)slot->data)->x, 
 			   ((hslot_type)slot->data)->y);
-    gdk_draw_pixmap (surface, draw_gc,
-		     get_slot_pixmap(), 0, 0, 
-		     ((hslot_type)slot->data)->x, 
-		     ((hslot_type)slot->data)->y, -1, -1);
+    slot_pixmap = get_slot_pixmap();
+    if (slot_pixmap != NULL)
+      gdk_draw_pixmap (surface, draw_gc,
+		       slot_pixmap, 0, 0, 
+		       ((hslot_type)slot->data)->x, 
+		       ((hslot_type)slot->data)->y, -1, -1);
     gdk_gc_set_clip_mask(draw_gc,NULL); 
   }
   draw_cards();
