@@ -117,8 +117,7 @@ io_gtk_init (void)
 
   
   /* make main window.  */
-  gtk_widget_push_visual (gdk_imlib_get_visual ());
-  gtk_widget_push_colormap (gdk_imlib_get_colormap ());
+  gtk_widget_push_colormap (gdk_rgb_get_cmap ());
   main_window = gnome_app_new ("freecell", _("Freecell"));
   gtk_signal_connect (GTK_OBJECT(main_window), "delete_event",
 		      GTK_SIGNAL_FUNC(callback_exit), NULL);
@@ -222,7 +221,6 @@ io_gtk_init (void)
   up_cursor = gdk_cursor_new (GDK_SB_UP_ARROW);
 
   gtk_widget_pop_colormap ();
-  gtk_widget_pop_visual ();
 
   stalled = 1;
 }
@@ -310,6 +308,11 @@ refresh_all (void)
     refresh_field(i);
 }
 
+callback_dialog_destroyed (GtkWidget *widget, gpointer data)
+{
+        mb = NULL;
+}
+
 
 void
 callback_restart (GtkWidget *widget, GdkEvent *event)
@@ -332,6 +335,11 @@ callback_restart (GtkWidget *widget, GdkEvent *event)
 				"clicked",
 				GTK_SIGNAL_FUNC(callback_restart_lose),
 				NULL);
+      gtk_signal_connect_object(GTK_OBJECT(mb),
+                                "destroy",
+				GTK_SIGNAL_FUNC(callback_dialog_destroyed),
+                                NULL);
+
       gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
       gtk_widget_show (mb);
     }
@@ -463,6 +471,11 @@ callback_new_with_seed (GtkWidget *widget, GdkEvent *event)
 				"clicked",
 				GTK_SIGNAL_FUNC(callback_new_with_seed_with_lose),
 				NULL);
+      gtk_signal_connect_object(GTK_OBJECT(mb),
+                                "destroy",
+				GTK_SIGNAL_FUNC(callback_dialog_destroyed),
+                                NULL);
+
       gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
       gtk_widget_show (mb);
     }
@@ -531,6 +544,11 @@ callback_new (GtkWidget *widget, GdkEvent *event)
 				"clicked",
 				GTK_SIGNAL_FUNC(callback_new_with_lose),
 				NULL);
+      gtk_signal_connect_object(GTK_OBJECT(mb),
+                                "destroy",
+				GTK_SIGNAL_FUNC(callback_dialog_destroyed),
+                                NULL);
+
       gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
       gtk_widget_show (mb);
     }
@@ -607,7 +625,6 @@ callback_exit_with_lose (GtkWidget *widget, gpointer data)
   mb = NULL;
 }
 
-
 void
 callback_exit (GtkWidget *widget, GdkEvent *event)
 {
@@ -630,6 +647,10 @@ callback_exit (GtkWidget *widget, GdkEvent *event)
 				"clicked",
 				GTK_SIGNAL_FUNC(callback_exit_with_lose),
 				NULL);
+      gtk_signal_connect_object(GTK_OBJECT(mb),
+				"destroy",
+				GTK_SIGNAL_FUNC(callback_dialog_destroyed),
+				NULL);
       gnome_dialog_set_parent (GNOME_DIALOG (mb), GTK_WINDOW (main_window));
       gtk_widget_show (mb);
     }
@@ -660,8 +681,10 @@ callback_about (GtkWidget *widget, GdkEvent *event)
   
   about = gnome_about_new (_("Freecell"), VERSION,
 			   "(C) 1998 Free Software Foundation, Inc.",
-			   (const char **)authors,
 			   _("Reimplement the popular solitaire card game."),
+			   (const char **)authors,
+			   NULL,
+			   NULL,
 			   NULL);
   gtk_widget_show (about);
 }
