@@ -1,4 +1,4 @@
-/* about-dialog.h
+/* option-dialog.h --
    Copyright (C) 1998 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and'or modify
@@ -13,9 +13,10 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+   USA */
 
-/* Written by Ryu Changwoo <cwryu@eve.kaist.ac.kr>. */
+/* Written by Changwoo Ryu <cwryu@adam.kaist.ac.kr>. */
 
 #ifndef __FREECELL__OPTION_DIALOG_H
 #define __FREECELL__OPTION_DIALOG_H
