@@ -360,7 +360,12 @@ about(GtkWidget *widget, gpointer data)
 		N_("Orest Zborowski - Curses Version (C) 1992"),
 		NULL
 	};
-
+        gchar *documenters[] = {
+                NULL
+        };
+        /* Translator credits */
+        gchar *translator_credits = _("translator_credits");
+        
 #ifdef ENABLE_NLS
 	{
 		int i=0;
@@ -370,8 +375,10 @@ about(GtkWidget *widget, gpointer data)
 
         about = gnome_about_new (appName, VERSION,
 				 _("(C) 1998 the Free Software Fundation"),
-				 (const char **)authors,
 				 _("Gnome Tali"),
+				 (const char **)authors,
+				 (const char **)documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 NULL);
         gtk_widget_show (about);
 	return FALSE;
@@ -454,9 +461,7 @@ LoadDicePixmaps(void)
                 /* Check for files w/pixmaps, override compiled defaults */
                 if (g_file_exists(dicefiles[i])) {
                         tmp = gnome_pixmap_new_from_file(dicefiles[i]);
-                        if (GNOME_PIXMAP(tmp)->pixmap == NULL) {
-                                gtk_widget_destroy(tmp);
-                        } else { 
+                        if (tmp != NULL) { 
                                 gtk_widget_destroy(dicePixmaps[0][i]);
                                 dicePixmaps[0][i] = tmp;
                         }
@@ -563,8 +568,9 @@ main (int argc, char *argv[])
 
 	gnome_score_init(appID);
 
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-	textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
 
 	/* Reset all yahtzee variables before parsing args */
         YahtzeeInit();
