@@ -24,6 +24,7 @@
 #include <libgnomeui/gnome-window-icon.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <games-clock.h>
 
 #include <sys/time.h>
 #include <string.h>
@@ -96,24 +97,25 @@ int session_xpos = -1;
 int session_ypos = -1;
 int session_position = 0;
 
-gchar tile_set[255];
-gchar tile_set_tmp[255];
+gchar *tile_set = NULL;
+gchar *tile_set_tmp = NULL;
 
 GdkGC *gridGC[2] = { 0 };
 
+static void new_network_game_cb(GtkWidget *widget, gpointer data);
+
 static const struct poptOption options[] = {
   {NULL, 'x', POPT_ARG_INT, &session_xpos, 0, NULL, NULL},
   {NULL, 'y', POPT_ARG_INT, &session_ypos, 0, NULL, NULL},
-#ifdef HAVE_ORBIT
-  {"ior", '\0', POPT_ARG_STRING, &ior, 0, N_("IOR of remote Iagno server"),
-   N_("IOR")},
-#endif
+  {"server", 's', POPT_ARG_STRING, &game_server, 0, N_("Iagno server to use")},
   {NULL, '\0', 0, NULL, 0}
 };
 
 GnomeUIInfo game_menu[] = {
         GNOMEUIINFO_MENU_NEW_GAME_ITEM(new_game_cb, NULL),
 
+	GNOMEUIINFO_ITEM(N_("New net_work game"), NULL, new_network_game_cb, NULL),
+
 	GNOMEUIINFO_SEPARATOR,
 
 	GNOMEUIINFO_MENU_UNDO_MOVE_ITEM(undo_move_cb, NULL),
@@ -255,29 +257,16 @@ void quit_game_cb(GtkWidget *widget, gpointer data)
 	}
 }
 
-void new_game_maybe(GtkWidget *widget, int button)
+static void
+new_network_game_cb(GtkWidget *widget, gpointer data)
 {
-	if (button == 0) {
-		network_new();
-		init_new_game();
-	}
+  network_new();
 }
 
 void new_game_cb(GtkWidget *widget, gpointer data)
 {
-	GtkWidget *box;
-
-	if(game_in_progress) {
-		box = gnome_message_box_new(_("Do you really want to end this game?"), GNOME_MESSAGE_BOX_QUESTION, GNOME_STOCK_BUTTON_YES, GNOME_STOCK_BUTTON_NO, NULL);
-		gnome_dialog_set_parent(GNOME_DIALOG(box), GTK_WINDOW(window));
-		gnome_dialog_set_default(GNOME_DIALOG(box), 0);
-		gtk_window_set_modal(GTK_WINDOW(box), TRUE);
-		gtk_signal_connect(GTK_OBJECT(box), "clicked", (GtkSignalFunc)new_game_maybe, NULL);
-		gtk_widget_show(box);
-	} else {
-		network_new();
-		init_new_game();
-	}
+  network_stop();
+  init_new_game();
 }
 
 void undo_move_cb(GtkWidget *widget, gpointer data)
@@ -334,9 +323,9 @@ void undo_move_cb(GtkWidget *widget, gpointer data)
 	gui_status();
 
 	if(timer_valid) {
-		gtk_clock_stop(GTK_CLOCK(time_display));
+		games_clock_stop(GAMES_CLOCK(time_display));
 		gtk_widget_set_sensitive(time_display, FALSE);
-		gtk_clock_set_seconds(GTK_CLOCK(time_display), 0);
+		games_clock_set_seconds(GAMES_CLOCK(time_display), 0);
 		timer_valid = 0;
 	}
 
@@ -357,9 +346,10 @@ void black_level_cb(GtkWidget *widget, gpointer data)
         black_computer_level = tmp;
 
         if(game_in_progress) {
-                gtk_clock_stop(GTK_CLOCK(time_display));
+
+                games_clock_stop(GAMES_CLOCK(time_display));
                 gtk_widget_set_sensitive(time_display, FALSE);
-                gtk_clock_set_seconds(GTK_CLOCK(time_display), 0);
+                games_clock_set_seconds(GAMES_CLOCK(time_display), 0);
                 timer_valid = 0;
         }
 
@@ -378,9 +368,9 @@ void white_level_cb(GtkWidget *widget, gpointer data)
         white_computer_level = tmp;
 
         if(game_in_progress) {
-                gtk_clock_stop(GTK_CLOCK(time_display));
+                games_clock_stop(GAMES_CLOCK(time_display));
                 gtk_widget_set_sensitive(time_display, FALSE);
-                gtk_clock_set_seconds(GTK_CLOCK(time_display), 0);
+                games_clock_set_seconds(GAMES_CLOCK(time_display), 0);
                 timer_valid = 0;
         }
 
@@ -392,6 +382,10 @@ void about_cb(GtkWidget *widget, gpointer data)
 	static GtkWidget *about;
 
 	const gchar *authors[] = {"Ian Peters", NULL};
+	const gchar *documenters[] = {
+	    			      NULL
+    	};
+    	const gchar *translator_credits = _("translator_credits");
 	
 	if (about != NULL) {
 		gdk_window_raise (about->window);
@@ -399,8 +393,15 @@ void about_cb(GtkWidget *widget, gpointer data)
 		return;
 	}
 
-	about = gnome_about_new(_("Iagno"), VERSION, _("(C) 1998 Ian Peters"),
-			(const char **)authors, _("Send comments and bug reports to: itp@gnu.org\nTiles under the General Public License."), NULL);
+	about = gnome_about_new(_("Iagno"), VERSION, 
+			        _("(C) 1998 Ian Peters"),
+				_("Send comments and bug reports to: itp@gnu.org\nTiles under the General Public License."), 
+				(const char **)authors, 
+				(const char **)documenters,
+				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				NULL);
+			
+			
 	gtk_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
 			(gtk_widget_destroyed), &about);
 	gnome_dialog_set_parent(GNOME_DIALOG(about), GTK_WINDOW(window));
@@ -472,7 +473,6 @@ void gui_draw_pixmap_buffer(gint which, gint x, gint y)
 void gui_draw_grid()
 {
 	int i;
-	GdkGC *gridcolor;
         
 	for(i = 1; i < 8; i++) {
 		gdk_draw_line(buffer_pixmap, gridGC[grid],
@@ -486,9 +486,12 @@ void gui_draw_grid()
 
 void load_pixmaps()
 {
-	char *tmp;
-	char *fname;
 	GdkPixbuf *image;
+	GError    *error = NULL;
+	char      *tmp;
+	char      *fname;
+
+	g_return_if_fail (tile_set != NULL && tile_set [0] != '0');
 
 	tmp = g_strconcat("iagno/", tile_set, NULL);
 	fname = gnome_unconditional_pixmap_file(tmp);
@@ -499,7 +502,13 @@ void load_pixmaps()
 		exit(1);
 	}
 
-	image = gdk_pixbuf_new_from_file(fname);
+	image = gdk_pixbuf_new_from_file(fname, &error);
+	if (error) {
+		g_warning (G_STRLOC ": gdk-pixbuf error %s\n", error->message);
+		g_error_free (error);
+		error = NULL;
+	}
+
 	gdk_pixbuf_render_pixmap_and_mask(image, &tiles_pixmap, &tiles_mask, 127);
 
 	gdk_pixbuf_unref(image);
@@ -577,67 +586,91 @@ gint flip_pixmaps(gpointer data)
 	return(TRUE);
 }
 
-void init_new_game()
+static void
+redraw_board(void)
 {
-	guint i, j;
+  guint i, j;
 
-	if (flip_final_id) {
-		gtk_timeout_remove(flip_final_id);
-		flip_final_id = 0;
-	}
+  gui_status();
 
-	if (black_computer_id) {
-		gtk_timeout_remove(black_computer_id);
-		black_computer_id = 0;
-	}
+  for(i = 0; i < 8; i++)
+    for(j = 0; j < 8; j++)
+      gui_draw_pixmap_buffer(pixmaps[i][j], i, j);
 
-	if (white_computer_id) {
-		gtk_timeout_remove(white_computer_id);
-		white_computer_id = 0;
-	}
+  gui_draw_grid();
+}
 
-	game_in_progress = 1;
-	move_count = 0;
+void
+clear_board(void)
+{
+  guint i, j;
 
-	for(i = 0; i < 8; i++)
-		for(j = 0; j < 8; j++)
-			board[i][j] = 0;
-	board[3][3] = WHITE_TURN;
-	board[3][4] = BLACK_TURN;
-	board[4][3] = BLACK_TURN;
-	board[4][4] = WHITE_TURN;
+  if (flip_final_id) {
+    gtk_timeout_remove(flip_final_id);
+    flip_final_id = 0;
+  }
 
-	bcount = 2;
-	wcount = 2;
+  if (black_computer_id) {
+    gtk_timeout_remove(black_computer_id);
+    black_computer_id = 0;
+  }
 
-	gui_status();
+  if (white_computer_id) {
+    gtk_timeout_remove(white_computer_id);
+    white_computer_id = 0;
+  }
 
-	memcpy(pixmaps, board, sizeof(gint8) * 8 * 8);
-	memcpy(game[0].board, board, sizeof(gint8) * 8 * 8);
+  game_in_progress = 0;
+  move_count = 0;
+  for(i = 0; i < 8; i++)
+    for(j = 0; j < 8; j++)
+      board[i][j] = 0;
 
-	for(i = 0; i < 8; i++)
-		for(j = 0; j < 8; j++)
-			gui_draw_pixmap_buffer(pixmaps[i][j], i, j);
+  memcpy(pixmaps, board, sizeof(gint8) * 8 * 8);
+  memcpy(game[0].board, board, sizeof(gint8) * 8 * 8);
 
-        gui_draw_grid();
+  bcount = 0;
+  wcount = 0;
 
-	whose_turn = BLACK_TURN;
-	gui_message(_("Dark's move"));
+  redraw_board();
+}
 
-	gtk_clock_stop(GTK_CLOCK(time_display));
-	gtk_clock_set_seconds(GTK_CLOCK(time_display), 0);
+void init_new_game(void)
+{
+  clear_board();
+  game_in_progress = 1;
+  move_count = 0;
 
-	if(black_computer_level ^ white_computer_level) {
-		if(!black_computer_level)
-			gtk_clock_start(GTK_CLOCK(time_display));
-		gtk_widget_set_sensitive(time_display, TRUE);
-		timer_valid = 1;
-	} else {
-		gtk_widget_set_sensitive(time_display, FALSE);
-		timer_valid = 0;
-	}
+  board[3][3] = WHITE_TURN;
+  board[3][4] = BLACK_TURN;
+  board[4][3] = BLACK_TURN;
+  board[4][4] = WHITE_TURN;
 
-	check_computer_players();
+  bcount = 2;
+  wcount = 2;
+
+  memcpy(pixmaps, board, sizeof(gint8) * 8 * 8);
+  memcpy(game[0].board, board, sizeof(gint8) * 8 * 8);
+
+  redraw_board();
+
+  whose_turn = BLACK_TURN;
+  gui_message(_("Dark's move"));
+
+  games_clock_stop(GAMES_CLOCK(time_display));
+  games_clock_set_seconds(GAMES_CLOCK(time_display), 0);
+
+  if(black_computer_level ^ white_computer_level) {
+   if(!black_computer_level)
+      games_clock_start(GAMES_CLOCK(time_display));
+    gtk_widget_set_sensitive(time_display, TRUE);
+    timer_valid = 1;
+  } else {
+    gtk_widget_set_sensitive(time_display, FALSE);
+    timer_valid = 0;
+  }
+
+  check_computer_players();
 }
 
 void create_window()
@@ -653,13 +686,11 @@ void create_window()
 
 	gnome_app_create_menus(GNOME_APP(window), mainmenu);
 
-	gtk_widget_push_visual (gdk_rgb_get_visual ());
 	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
 	drawing_area = gtk_drawing_area_new();
 
 	gtk_widget_pop_colormap ();
-	gtk_widget_pop_visual ();
 
 	gnome_app_set_contents(GNOME_APP(window), drawing_area);
 
@@ -706,12 +737,11 @@ void create_window()
 
 	gtk_table_attach(GTK_TABLE(table), sep, 6, 7, 0, 1, 0, GTK_FILL, 3, 3);
 
-	time_display = gtk_clock_new(GTK_CLOCK_INCREASING);
+	time_display = games_clock_new();
 	gtk_widget_set_sensitive(time_display, FALSE);
 	gtk_widget_show(time_display);
 
 	gtk_table_attach(GTK_TABLE(table), time_display, 7, 8, 0, 1, 0, 0, 3, 1);
-
 	gtk_widget_show(table);
 
 	gtk_box_pack_start(GTK_BOX(appbar), table, FALSE, TRUE, 0);
@@ -793,6 +823,10 @@ void set_bg_color()
 	bgcolor.pixel = 0xFFFFFF - bgcolor.pixel;
 	gdk_gc_set_background (gridGC [1],&bgcolor);
 	gdk_gc_set_foreground (gridGC [1],&bgcolor);
+
+	gdk_gc_set_line_attributes (gridGC [1], 0,
+				    GDK_LINE_ON_OFF_DASH,
+				    GDK_CAP_BUTT, GDK_JOIN_MITER);
 	
 	gdk_image_destroy (tmpimage);
 }
@@ -831,23 +865,18 @@ static int save_state(GnomeClient *client, gint phase, GnomeRestartStyle save_st
 int main(int argc, char **argv)
 {
 	GnomeClient *client;
-	CORBA_def(CORBA_Environment ev;)
 	struct timeval tv;
 
 	gnome_score_init("iagno");
 
-	bindtextdomain(PACKAGE, GNOMELOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain(GETTEXT_PACKAGE);
 
 	gettimeofday(&tv, NULL);
 	srand(tv.tv_usec);
 
-#ifdef HAVE_ORBIT
-	CORBA_exception_init (&ev);
-	orb = gnome_CORBA_init_with_popt_table ("iagno", VERSION, &argc, argv, options, 0, NULL, GNORBA_INIT_SERVER_FUNC|GNORBA_INIT_DISABLE_COOKIES, &ev);
-#else
 	gnome_init_with_popt_table("iagno", VERSION, argc, argv, options, 0, NULL);
-#endif
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/iagno.png");
 	client= gnome_master_client();
 
@@ -873,8 +902,6 @@ int main(int argc, char **argv)
 
 	set_bg_color();
 
-	network_init();
-
 	gtk_main();
 
 	return 0;
